Enum EncodedImageFormat
Source pub enum EncodedImageFormat {
Show 14 variants
BMP = 0,
GIF = 1,
ICO = 2,
JPEG = 3,
PNG = 4,
WBMP = 5,
WEBP = 6,
PKM = 7,
KTX = 8,
ASTC = 9,
DNG = 10,
HEIF = 11,
AVIF = 12,
JPEGXL = 13,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.