pub struct BackendState(/* private fields */);Implementations
Sourceimpl BackendState
impl BackendState
pub const RENDER_TARGET: BackendState
pub const TEXTURE_BINDING: BackendState
pub const VIEW: BackendState
pub const BLEND: BackendState
pub const MSAA_ENABLE: BackendState
pub const VERTEX: BackendState
pub const STENCIL: BackendState
pub const PIXEL_STORE: BackendState
pub const PROGRAM: BackendState
pub const FIXED_FUNCTION: BackendState
pub const MISC: BackendState
Sourceimpl BackendState
impl BackendState
Sourcepub const fn empty() -> BackendState
pub const fn empty() -> BackendState
Get a flags value with all bits unset.
Sourcepub const fn all() -> BackendState
pub const fn all() -> BackendState
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<BackendState>
pub const fn from_bits(bits: u32) -> Option<BackendState>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> BackendState
pub const fn from_bits_truncate(bits: u32) -> BackendState
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> BackendState
pub const fn from_bits_retain(bits: u32) -> BackendState
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<BackendState>
pub fn from_name(name: &str) -> Option<BackendState>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: BackendState) -> bool
pub const fn intersects(&self, other: BackendState) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: BackendState) -> bool
pub const fn contains(&self, other: BackendState) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: BackendState)
pub fn insert(&mut self, other: BackendState)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: BackendState)
pub fn remove(&mut self, other: BackendState)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: BackendState)
pub fn toggle(&mut self, other: BackendState)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: BackendState, value: bool)
pub fn set(&mut self, other: BackendState, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: BackendState) -> BackendState
pub const fn intersection(self, other: BackendState) -> BackendState
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: BackendState) -> BackendState
pub const fn union(self, other: BackendState) -> BackendState
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: BackendState) -> BackendState
pub const fn difference(self, other: BackendState) -> BackendState
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: BackendState) -> BackendState
pub const fn symmetric_difference(self, other: BackendState) -> BackendState
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> BackendState
pub const fn complement(self) -> BackendState
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl BackendState
impl BackendState
Sourcepub const fn iter(&self) -> Iter<BackendState>
pub const fn iter(&self) -> Iter<BackendState>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BackendState>
pub const fn iter_names(&self) -> IterNames<BackendState>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.