pub struct Paragraph;Implementations
Sourceimpl Paragraph
impl Paragraph
pub fn max_width(&self) -> f32
pub fn height(&self) -> f32
pub fn min_intrinsic_width(&self) -> f32
pub fn max_intrinsic_width(&self) -> f32
pub fn alphabetic_baseline(&self) -> f32
pub fn ideographic_baseline(&self) -> f32
pub fn longest_line(&self) -> f32
pub fn did_exceed_max_lines(&self) -> bool
pub fn layout(&mut self, _width: f32)
pub fn paint(&self, _canvas: &Canvas, _p: impl Into<Point>)
Sourcepub fn get_rects_for_range(
&self,
_range: Range<usize>,
_rect_height_style: RectHeightStyle,
_rect_width_style: RectWidthStyle,
) -> Vec<TextBox>
pub fn get_rects_for_range( &self, _range: Range<usize>, _rect_height_style: RectHeightStyle, _rect_width_style: RectWidthStyle, ) -> Vec<TextBox>
Returns a vector of bounding boxes that enclose all text between start and end glyph indexes, including start and excluding end